@@ -222,8 +222,8 @@ class BaseSQLToGCSOperator(BaseOperator):
     def _write_rows_to_parquet(parquet_writer: pq.ParquetWriter, rows):
         rows_pydic: dict[str, list[Any]] = {col: [] for col in parquet_writer.schema.names}
         for row in rows:
-            for ind, col in enumerate(parquet_writer.schema.names):
-                rows_pydic[col].append(row[ind])
+            for cell, col in zip(row, parquet_writer.schema.names):
+                rows_pydic[col].append(cell)
         tbl = pa.Table.from_pydict(rows_pydic, parquet_writer.schema)
         parquet_writer.write_table(tbl)
 
@@ -235,7 +235,7 @@ class BaseSQLToGCSOperator(BaseOperator):
             names in GCS, and values are file handles to local files that
             contain the data for the GCS objects.
         """
-        org_schema = list(map(lambda schema_tuple: schema_tuple[0], cursor.description))
+        org_schema = [schema_tuple[0] for schema_tuple in cursor.description]
         schema = [column for column in org_schema if column not in self.exclude_columns]
 
         col_type_dict = self._get_col_type_dict()
@@ -293,12 +293,12 @@ class BaseSQLToGCSOperator(BaseOperator):
             if self.export_format == "csv":
                 row = self.convert_types(schema, col_type_dict, row)
                 if self.null_marker is not None:
-                    row = [value if value is not None else self.null_marker for value in row]
+                    row = [value or self.null_marker for value in row]
                 csv_writer.writerow(row)
             elif self.export_format == "parquet":
                 row = self.convert_types(schema, col_type_dict, row)
                 if self.null_marker is not None:
-                    row = [value if value is not None else self.null_marker for value in row]
+                    row = [value or self.null_marker for value in row]
                 rows_buffer.append(row)
                 if len(rows_buffer) >= self.parquet_row_group_size:
                     self._write_rows_to_parquet(parquet_writer, rows_buffer)
@@ -371,9 +371,7 @@ class BaseSQLToGCSOperator(BaseOperator):
         return file_mime_type
 
     def _configure_csv_file(self, file_handle, schema):
-        """Configure a csv writer with the file_handle and write schema
-        as headers for the new file.
-        """
+        """Configure a csv writer with the file_handle and write schema as headers for the new file."""
         csv_writer = csv.writer(file_handle, delimiter=self.field_delimiter)
         csv_writer.writerow(schema)
         return csv_writer
@@ -438,9 +436,9 @@ class BaseSQLToGCSOperator(BaseOperator):
 
     def _write_local_schema_file(self, cursor):
         """
-        Takes a cursor, and writes the BigQuery schema for the results to a
-        local file system. Schema for database will be read from cursor if
-        not specified.
+        Takes a cursor, and writes the BigQuery schema for the results to a local file system.
+
+        Schema for database will be read from cursor if not specified.
 
         :return: A dictionary where key is a filename to be used as an object
             name in GCS, and values are file handles to local files that
