@@ -74,33 +74,31 @@ class BigQueryInsertJobTrigger(BaseTrigger):
     async def run(self) -> AsyncIterator[TriggerEvent]:  # type: ignore[override]
         """Gets current job execution status and yields a TriggerEvent."""
         hook = self._get_async_hook()
-        while True:
-            try:
-                # Poll for job execution status
-                response_from_hook = await hook.get_job_status(job_id=self.job_id, project_id=self.project_id)
-                self.log.debug("Response from hook: %s", response_from_hook)
-
-                if response_from_hook == "success":
+        try:
+            while True:
+                job_status = await hook.get_job_status(job_id=self.job_id, project_id=self.project_id)
+                if job_status["status"] == "success":
                     yield TriggerEvent(
                         {
                             "job_id": self.job_id,
-                            "status": "success",
-                            "message": "Job completed",
+                            "status": job_status["status"],
+                            "message": job_status["message"],
                         }
                     )
                     return
-                elif response_from_hook == "pending":
-                    self.log.info("Query is still running...")
-                    self.log.info("Sleeping for %s seconds.", self.poll_interval)
-                    await asyncio.sleep(self.poll_interval)
-                else:
-                    yield TriggerEvent({"status": "error", "message": response_from_hook})
+                elif job_status["status"] == "error":
+                    yield TriggerEvent(job_status)
                     return
-
-            except Exception as e:
-                self.log.exception("Exception occurred while checking for query completion")
-                yield TriggerEvent({"status": "error", "message": str(e)})
-                return
+                else:
+                    self.log.info(
+                        "Bigquery job status is %s. Sleeping for %s seconds.",
+                        job_status["status"],
+                        self.poll_interval,
+                    )
+                    await asyncio.sleep(self.poll_interval)
+        except Exception as e:
+            self.log.exception("Exception occurred while checking for query completion")
+            yield TriggerEvent({"status": "error", "message": str(e)})
 
     def _get_async_hook(self) -> BigQueryAsyncHook:
         return BigQueryAsyncHook(gcp_conn_id=self.conn_id)
@@ -126,20 +124,20 @@ class BigQueryCheckTrigger(BigQueryInsertJobTrigger):
     async def run(self) -> AsyncIterator[TriggerEvent]:  # type: ignore[override]
         """Gets current job execution status and yields a TriggerEvent."""
         hook = self._get_async_hook()
-        while True:
-            try:
+        try:
+            while True:
                 # Poll for job execution status
-                response_from_hook = await hook.get_job_status(job_id=self.job_id, project_id=self.project_id)
-                if response_from_hook == "success":
+                job_status = await hook.get_job_status(job_id=self.job_id, project_id=self.project_id)
+                if job_status["status"] == "success":
                     query_results = await hook.get_job_output(job_id=self.job_id, project_id=self.project_id)
-
                     records = hook.get_records(query_results)
 
                     # If empty list, then no records are available
                     if not records:
                         yield TriggerEvent(
                             {
-                                "status": "success",
+                                "status": job_status["status"],
+                                "message": job_status["message"],
                                 "records": None,
                             }
                         )
@@ -149,23 +147,25 @@ class BigQueryCheckTrigger(BigQueryInsertJobTrigger):
                         first_record = records.pop(0)
                         yield TriggerEvent(
                             {
-                                "status": "success",
+                                "status": job_status["status"],
+                                "message": job_status["message"],
                                 "records": first_record,
                             }
                         )
                         return
-
-                elif response_from_hook == "pending":
-                    self.log.info("Query is still running...")
-                    self.log.info("Sleeping for %s seconds.", self.poll_interval)
-                    await asyncio.sleep(self.poll_interval)
-                else:
-                    yield TriggerEvent({"status": "error", "message": response_from_hook})
+                elif job_status["status"] == "error":
+                    yield TriggerEvent({"status": "error", "message": job_status["message"]})
                     return
-            except Exception as e:
-                self.log.exception("Exception occurred while checking for query completion")
-                yield TriggerEvent({"status": "error", "message": str(e)})
-                return
+                else:
+                    self.log.info(
+                        "Bigquery job status is %s. Sleeping for %s seconds.",
+                        job_status["status"],
+                        self.poll_interval,
+                    )
+                    await asyncio.sleep(self.poll_interval)
+        except Exception as e:
+            self.log.exception("Exception occurred while checking for query completion")
+            yield TriggerEvent({"status": "error", "message": str(e)})
 
 
 class BigQueryGetDataTrigger(BigQueryInsertJobTrigger):
@@ -198,33 +198,35 @@ class BigQueryGetDataTrigger(BigQueryInsertJobTrigger):
     async def run(self) -> AsyncIterator[TriggerEvent]:  # type: ignore[override]
         """Gets current job execution status and yields a TriggerEvent with response data."""
         hook = self._get_async_hook()
-        while True:
-            try:
+        try:
+            while True:
                 # Poll for job execution status
-                response_from_hook = await hook.get_job_status(job_id=self.job_id, project_id=self.project_id)
-                if response_from_hook == "success":
+                job_status = await hook.get_job_status(job_id=self.job_id, project_id=self.project_id)
+                if job_status["status"] == "success":
                     query_results = await hook.get_job_output(job_id=self.job_id, project_id=self.project_id)
                     records = hook.get_records(query_results=query_results, as_dict=self.as_dict)
-                    self.log.debug("Response from hook: %s", response_from_hook)
+                    self.log.debug("Response from hook: %s", job_status["status"])
                     yield TriggerEvent(
                         {
                             "status": "success",
-                            "message": response_from_hook,
+                            "message": job_status["message"],
                             "records": records,
                         }
                     )
                     return
-                elif response_from_hook == "pending":
-                    self.log.info("Query is still running...")
-                    self.log.info("Sleeping for %s seconds.", self.poll_interval)
-                    await asyncio.sleep(self.poll_interval)
-                else:
-                    yield TriggerEvent({"status": "error", "message": response_from_hook})
+                elif job_status["status"] == "error":
+                    yield TriggerEvent(job_status)
                     return
-            except Exception as e:
-                self.log.exception("Exception occurred while checking for query completion")
-                yield TriggerEvent({"status": "error", "message": str(e)})
-                return
+                else:
+                    self.log.info(
+                        "Bigquery job status is %s. Sleeping for %s seconds.",
+                        job_status["status"],
+                        self.poll_interval,
+                    )
+                    await asyncio.sleep(self.poll_interval)
+        except Exception as e:
+            self.log.exception("Exception occurred while checking for query completion")
+            yield TriggerEvent({"status": "error", "message": str(e)})
 
 
 class BigQueryIntervalCheckTrigger(BigQueryInsertJobTrigger):
@@ -303,8 +305,8 @@ class BigQueryIntervalCheckTrigger(BigQueryInsertJobTrigger):
     async def run(self) -> AsyncIterator[TriggerEvent]:  # type: ignore[override]
         """Gets current job execution status and yields a TriggerEvent."""
         hook = self._get_async_hook()
-        while True:
-            try:
+        try:
+            while True:
                 first_job_response_from_hook = await hook.get_job_status(
                     job_id=self.first_job_id, project_id=self.project_id
                 )
@@ -312,7 +314,10 @@ class BigQueryIntervalCheckTrigger(BigQueryInsertJobTrigger):
                     job_id=self.second_job_id, project_id=self.project_id
                 )
 
-                if first_job_response_from_hook == "success" and second_job_response_from_hook == "success":
+                if (
+                    first_job_response_from_hook["status"] == "success"
+                    and second_job_response_from_hook["status"] == "success"
+                ):
                     first_query_results = await hook.get_job_output(
                         job_id=self.first_job_id, project_id=self.project_id
                     )
@@ -356,20 +361,22 @@ class BigQueryIntervalCheckTrigger(BigQueryInsertJobTrigger):
                         }
                     )
                     return
-                elif first_job_response_from_hook == "pending" or second_job_response_from_hook == "pending":
+                elif (
+                    first_job_response_from_hook["status"] == "pending"
+                    or second_job_response_from_hook["status"] == "pending"
+                ):
                     self.log.info("Query is still running...")
                     self.log.info("Sleeping for %s seconds.", self.poll_interval)
                     await asyncio.sleep(self.poll_interval)
                 else:
                     yield TriggerEvent(
-                        {"status": "error", "message": second_job_response_from_hook, "data": None}
+                        {"status": "error", "message": second_job_response_from_hook["message"], "data": None}
                     )
                     return
 
-            except Exception as e:
-                self.log.exception("Exception occurred while checking for query completion")
-                yield TriggerEvent({"status": "error", "message": str(e)})
-                return
+        except Exception as e:
+            self.log.exception("Exception occurred while checking for query completion")
+            yield TriggerEvent({"status": "error", "message": str(e)})
 
 
 class BigQueryValueCheckTrigger(BigQueryInsertJobTrigger):
@@ -431,28 +438,29 @@ class BigQueryValueCheckTrigger(BigQueryInsertJobTrigger):
     async def run(self) -> AsyncIterator[TriggerEvent]:  # type: ignore[override]
         """Gets current job execution status and yields a TriggerEvent."""
         hook = self._get_async_hook()
-        while True:
-            try:
+        try:
+            while True:
                 # Poll for job execution status
                 response_from_hook = await hook.get_job_status(job_id=self.job_id, project_id=self.project_id)
-                if response_from_hook == "success":
+                if response_from_hook["status"] == "success":
                     query_results = await hook.get_job_output(job_id=self.job_id, project_id=self.project_id)
                     records = hook.get_records(query_results)
                     records = records.pop(0) if records else None
                     hook.value_check(self.sql, self.pass_value, records, self.tolerance)
                     yield TriggerEvent({"status": "success", "message": "Job completed", "records": records})
                     return
-                elif response_from_hook == "pending":
+                elif response_from_hook["status"] == "pending":
                     self.log.info("Query is still running...")
                     self.log.info("Sleeping for %s seconds.", self.poll_interval)
                     await asyncio.sleep(self.poll_interval)
                 else:
-                    yield TriggerEvent({"status": "error", "message": response_from_hook, "records": None})
+                    yield TriggerEvent(
+                        {"status": "error", "message": response_from_hook["message"], "records": None}
+                    )
                     return
-            except Exception as e:
-                self.log.exception("Exception occurred while checking for query completion")
-                yield TriggerEvent({"status": "error", "message": str(e)})
-                return
+        except Exception as e:
+            self.log.exception("Exception occurred while checking for query completion")
+            yield TriggerEvent({"status": "error", "message": str(e)})
 
 
 class BigQueryTableExistenceTrigger(BaseTrigger):
@@ -502,8 +510,8 @@ class BigQueryTableExistenceTrigger(BaseTrigger):
 
     async def run(self) -> AsyncIterator[TriggerEvent]:  # type: ignore[override]
         """Will run until the table exists in the Google Big Query."""
-        while True:
-            try:
+        try:
+            while True:
                 hook = self._get_async_hook()
                 response = await self._table_exists(
                     hook=hook, dataset=self.dataset_id, table_id=self.table_id, project_id=self.project_id
@@ -512,10 +520,9 @@ class BigQueryTableExistenceTrigger(BaseTrigger):
                     yield TriggerEvent({"status": "success", "message": "success"})
                     return
                 await asyncio.sleep(self.poll_interval)
-            except Exception as e:
-                self.log.exception("Exception occurred while checking for Table existence")
-                yield TriggerEvent({"status": "error", "message": str(e)})
-                return
+        except Exception as e:
+            self.log.exception("Exception occurred while checking for Table existence")
+            yield TriggerEvent({"status": "error", "message": str(e)})
 
     async def _table_exists(
         self, hook: BigQueryTableAsyncHook, dataset: str, table_id: str, project_id: str
@@ -536,7 +543,7 @@ class BigQueryTableExistenceTrigger(BaseTrigger):
                     dataset=dataset, table_id=table_id, project_id=project_id, session=session
                 )
                 response = await client.get()
-                return True if response else False
+                return bool(response)
             except ClientResponseError as err:
                 if err.status == 404:
                     return False
@@ -581,8 +588,8 @@ class BigQueryTablePartitionExistenceTrigger(BigQueryTableExistenceTrigger):
         job_id = None
         while True:
             if job_id is not None:
-                status = await hook.get_job_status(job_id=job_id, project_id=self.project_id)
-                if status == "success":
+                job_status = await hook.get_job_status(job_id=job_id, project_id=self.project_id)
+                if job_status["status"] == "success":
                     is_partition = await self._partition_exists(
                         hook=hook, job_id=job_id, project_id=self.project_id
                     )
@@ -595,8 +602,8 @@ class BigQueryTablePartitionExistenceTrigger(BigQueryTableExistenceTrigger):
                         )
                         return
                     job_id = None
-                elif status == "error":
-                    yield TriggerEvent({"status": "error", "message": status})
+                elif job_status["status"] == "error":
+                    yield TriggerEvent(job_status)
                     return
                 self.log.info("Sleeping for %s seconds.", self.poll_interval)
                 await asyncio.sleep(self.poll_interval)
